#
# spec file for package adriconf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           adriconf
Version:        2.7.2
Release:        1.2
Summary:        Advanced DRI Configurator
License:        GPL-3.0-only
Group:          System/Packages
URL:            https://gitlab.freedesktop.org/mesa/adriconf
Source0:        https://gitlab.freedesktop.org/mesa/adriconf/-/archive/v%{version}/adriconf-v%{version}.tar.bz2
Source1:        adriconf.desktop
Source2:        driconf-icon.png
BuildRequires:  Mesa-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libboost_filesystem-devel >= 1.60
BuildRequires:  libboost_locale-devel >= 1.60
BuildRequires:  libboost_system-devel >= 1.60
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atkmm-2.36)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gtkmm-4.0)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpci)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(pugixml)

%description
adriconf (Advanced DRI CONFigurator) is a GUI tool used to configure open
source graphics drivers. It works by setting options and writing them to
the standard drirc file used by the Mesa drivers.

%lang_package

%prep
%autosetup -n %{name}-v%{version}

%build
%cmake \
	-DENABLE_UNIT_TESTS=OFF
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}/%{_datadir}/{applications,pixmaps}
install -Dpm 0755 %{SOURCE1} \
  %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -Dpm 0755 %{SOURCE2} \
  %{buildroot}/%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/%{name}.desktop
%find_lang %{name}

%files
%license LICENSE
%{_bindir}/adriconf
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%files lang -f %{name}.lang

%changelog
* Mon Jul 22 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.7.11:
  * Updated dependencies
* Tue Oct 10 2023 ming li <mli@suse.com>
- Update to version 2.7.1:
  * Fix build with GCC 13
- The fix-missing-include.patch was removed from the package.
* Fri May 26 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.7.0:
  * Adjusted app to better handle very small screens
  * Dropped dependency on X11
  * Support new executable_regexp and sha1 profile attributes
* Tue Mar 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-missing-include.patch: Add missing include exposed by
  gcc13.
* Wed Mar 15 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.6.0:
  * No changelog provided
* Tue Dec  6 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.5.1:
  * No changelog provided
* Mon Mar 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.5.0:
  * No changelog provided
* Tue Apr 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.4.1
  * No source changes
- Fixed dependencies
  * GTK+ 0.24+ is required for ComboBoxExtra
  * libXML++ is also supported in version 5 (used in Factory)
* Wed Nov  4 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.4:
  * Renamed application from br.com.jeanhertel.adriconf to
    org.freedesktop.adriconf.
  * Handle string and float options.
  * Add Polish translations. @baryluk
  * Make various cosmetic fixes.
- Changes for older versions in 2.* series:
  * Rename application to org.freedesktop.adriconf
  * Make sure themes don't add shadows to button.
  * Add tooltips to add profile screen.
  * Fix Spin Button fields, so that increment/decrement fields are
    correctly visible.
  * Improve Switch buttons with more visible colors.
  * Small fix fox incorrect shadows with default GTK+ theme.
  * User Interface is dark by default
  * Completely removed dialogs and replaced them with screens,
    giving a more natural navigation.
  * Profiles are now saved independently giving the user more
    control on what to save.
  * Mesa-defined profiles are not shown anymore, avoiding previous
    confusion on what the user added and what is defined by mesa
    itself.
  * Better validate when the user adds a new profile.
  * Bug-fix: When switching the GPU on PRIME settings now we keep
    the same application selected.
* Sat May  9 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.7:
  * Add IT translation. @albanobattistella
  * Fix incorrect handling of system wide options when multiple
    drivers are defined. @jlhertel
  * Add option to change default config directories. @jlhertel
  * Add code of conduct. @jlhertel
* Fri Feb 14 2020 Martin Pluskal <mpluskal@suse.com>
- Initial changelog entry for version 1.6.1
  * Package based on one by Sergey Kondakov (X0F)
